[![PyPI version](https://img.shields.io/pypi/status/ivr.svg)](https://www.invite-comm.jp)  [![PyPI version](https://badge.fury.io/py/ivr.svg)](https://badge.fury.io/py/ivr)  [![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)  [![Documentation Status](https://readthedocs.org/projects/asterisk-ivr/badge/?version=latest)](http://asterisk-ivr.readthedocs.io/en/latest/?badge=latest)


My first PyPI version.  Testing dependencies and working on the structure.

# asterisk-ivr

_Not much to see here_

Currently my work area.  Doesn't do much right now.

```
├── ivr
│   ├── __init__.py			
│   ├── ivr.py
│   └── test.py
│
├── pigeonhole | WHERE I STASH STUFF FOR TESTING
│   ├── test - Testing Settings Files
│   |   ├── settings.conf
│   |   └── simple.py
│   ├── README.md
│   └── stuff that MAY or MAY NOT work for you
|
├── README.md
├── LICENSE.txt
├── setup.cfg
└── setup.py
```
